

models.Activity
===============

pykechain.models.Activity2
--------------------------

.. autoclass:: pykechain.models.Activity2
   :members:


pykechain.models.Activity
-------------------------

.. autoclass:: pykechain.models.Activity
   :members:
